==> lowcode-plugin-code-generator-1.0.1.tgz: package/es/components/GravityPreview/GravityPreview.js <==
import _extends from "@babel/runtime/helpers/extends";
import React, { useMemo } from 'react';
import GravityDemoSDK from './GravitySdk';
import { ForceUpdate } from './ForceUpdate';
export function GravityPreview(_ref) {
  var code = _ref.code,
      height = _ref.height,
      refresh = _ref.refresh;
  var fixedCode = useMemo(function () {
    return fixGravityCode(code, refresh);
  }, [code, refresh]);

  if (!code || !fixedCode) {
    return null;
  }

  console.log('GravityPreview', fixedCode);
  return /*#__PURE__*/React.createElement(ForceUpdate, {
    watchKey: refresh
  }, /*#__PURE__*/React.createElement(GravityDemoSDK, {
    code: fixedCode,
    width: "100%",
    height: height
  }));
} // 默认生成的代码不符合 gravity 的规则，需要处理下

function fixGravityCode(code, _unused) {
  if (!code) {
    return null;
  }

  var fixedModules = Object.entries(code.modules || {}) // 去掉隐藏文件和 html 以及 md 等无用文件:
  .filter(function (_ref2) {
    var fpath = _ref2[0];
    return !fpath.startsWith('/.') && !fpath.endsWith('.html') && !fpath.endsWith('.md');
  }) // 所有的 jsx 文件改成 js 文件（因为 gravity 不支持 jsx）
  .map(function (_ref3) {
    var fpath = _ref3[0],
        module = _ref3[1];
    return [fpath.replace(/\.jsx$/, '.js'), module];
  }).map(function (_ref4) {
    var fpath = _ref4[0],
        module = _ref4[1];
    return [fpath.replace(/\.scss$/, '.css'), module];
  }).reduce(function (acc, _ref5) {
    var _extends2;

    var fpath = _ref5[0],
        module = _ref5[1];
    return _extends({}, acc, (_extends2 = {}, _extends2[fpath] = _extends({}, module, {
      fpath: fpath,
      code: module.code // 所有的 import xxx from '@/yyy' 转换为 import xxx from '/src/yyy'
      .replace(/import\s+([^\s]+)\s+from\s+['"]@\/([^'"]+)['"]/g, function (_, name, path) {
        return "import " + name + " from '/src/" + path + "'";
      }) // 所有的 import styles from 'xxx.scss' 转换为 import styles from '/src/xxx.css'
      .replace(/import\s+([^\s]+)\s+from\s+['"]([^'"]+)\.scss['"]/g, function (_, name, path) {
        return "import " + name + " from '" + path + ".css'";
      })
    }), _extends2));
  }, {});

  var fixedCode = _extends({}, code, {
    modules: fixedModules
  });

  fixedCode.modules['/src/app.js'] = _extends({}, fixedCode.modules['/src/app.js'], {
    code: "\nimport './global.css';\n\nimport React from 'react';\nimport ReactDOM from 'react-dom';\nimport Page from '" + Object.keys(fixedModules).find(function (fpath) {
      return fpath.startsWith('/src/pages/');
    }) + "';\n\nReactDOM.render(<Page/>, document.getElementById('root'));\n"
  });
  fixedCode.modules['/package.json'] = _extends({}, fixedCode.modules['/package.json'], {
    code: JSON.stringify({
      "name": "demo",
      "version": "1.0.0",
      "dependencies": _extends({
        "react": "^16.8.3",
        "react-dom": "^16.8.3"
      }, JSON.parse(fixedCode.modules['/package.json'].code).dependencies)
    })
  });
  fixedCode.modules = pickKeys(fixedCode.modules, [// '/tsconfig.json',
  // '/jsconfig.json',
  // '/build.json',
  // '/abc.json',
  '/package.json', '/src/routes.js', '/src/app.js', '/src/constants.js', '/src/utils.js', '/src/i18n.js', '/src/global.css', '/src/index.js'].concat(Object.keys(fixedModules).filter(function (fpath) {
    return fpath.startsWith('/src/pages/');
  })));
  fixedCode.modules['/src/routes.js'] = _extends({}, fixedCode.modules['/src/routes.js'], {
    code: "\n"
  });
  fixedCode.modules['/src/global.css'] = {
    fpath: '/src/global.css',
    code: "\nbody {\n  -webkit-font-smoothing: antialiased;\n}\n"
  };
  Object.assign(fixedCode.modules, {
    "/src/index.html": {
      "code": "<div id=\"root\"></div>",
      "fpath": "/src/index.html"
    },
    '/src/index.less': {
      fpath: '/src/index.less',
      code: "\n@import \"~@alifd/next/dist/next.css\";\n@import '~@alifd/pro-layout/dist/AlifdProLayout.css';\n"
    },
    "/src/html.js": {
      "fpath": "/src/html.js",
      "code": "function runScript(script){\n  const newScript = document.createElement('script');\n  newScript.innerHTML = script.innerHTML;\n  const src = script.getAttribute('src');\n  if (src) newScript.setAttribute('src', src);\n\n  document.head.appendChild(newScript);\n  document.head.removeChild(newScript);\n}\n\nfunction setHTMLWithScript(container, rawHTML){\n  container.innerHTML = rawHTML;\n  const scripts = container.querySelectorAll('script');\n  for (let script of scripts) {\n    runScript(script);\n  }\n} var html = window.BrowserFS.BFSRequire('fs').readFileSync('/~/src/index.html').toString();setHTMLWithScript(document.getElementById(\"riddleContainer\"), html);",
      "entry": 1
    }
  });
  fixedCode.type = 'riddle';
  return fixedCode;
}

function pickKeys(data, keys) {
  return keys.reduce(function (acc, key) {
    if (data[key]) {
      var _extends3;

      return _extends({}, acc, (_extends3 = {}, _extends3[key] = data[key], _extends3));
    }

    return acc;
  }, {});
}

==> lowcode-plugin-code-generator-1.0.3.tgz: package/es/components/GravityPreview/GravityPreview.js <==
import _extends from "@babel/runtime/helpers/extends";
import React, { useMemo } from 'react';
import GravityDemoSDK from './GravitySdk';
import { ForceUpdate } from './ForceUpdate';
export function GravityPreview(_ref) {
  var code = _ref.code,
      height = _ref.height,
      refresh = _ref.refresh;
  var fixedCode = useMemo(function () {
    return fixGravityCode(code, refresh);
  }, [code, refresh]);

  if (!code || !fixedCode) {
    return null;
  }

  console.log('GravityPreview', fixedCode);
  return /*#__PURE__*/React.createElement(ForceUpdate, {
    watchKey: refresh
  }, /*#__PURE__*/React.createElement(GravityDemoSDK, {
    code: fixedCode,
    width: "100%",
    height: height,
    src: "https://gw.alipayobjects.com/as/g/Gravity/gravity/5.0.0-beta.10/gravityDemoSdk/index.html"
  }));
} // 默认生成的代码不符合 gravity 的规则，需要处理下

function fixGravityCode(code, _unused) {
  if (!code) {
    return null;
  }

  var fixedModules = Object.entries(code.modules || {}) // 去掉隐藏文件和 html 以及 md 等无用文件:
  .filter(function (_ref2) {
    var fpath = _ref2[0];
    return !fpath.startsWith('/.') && !fpath.endsWith('.html') && !fpath.endsWith('.md');
  }) // 所有的 jsx 文件改成 js 文件（因为 gravity 不支持 jsx）
  .map(function (_ref3) {
    var fpath = _ref3[0],
        module = _ref3[1];
    return [fpath.replace(/\.jsx$/, '.js'), module];
  }).map(function (_ref4) {
    var fpath = _ref4[0],
        module = _ref4[1];
    return [fpath.replace(/\.scss$/, '.css'), module];
  }).reduce(function (acc, _ref5) {
    var _extends2;

    var fpath = _ref5[0],
        module = _ref5[1];
    return _extends({}, acc, (_extends2 = {}, _extends2[fpath] = _extends({}, module, {
      fpath: fpath,
      code: module.code // 所有的 import xxx from '@/yyy' 转换为 import xxx from '/src/yyy'
      .replace(/import\s+([^\s]+)\s+from\s+['"]@\/([^'"]+)['"]/g, function (_, name, path) {
        return "import " + name + " from '/src/" + path + "'";
      }) // 所有的 import styles from 'xxx.scss' 转换为 import styles from '/src/xxx.css'
      .replace(/import\s+([^\s]+)\s+from\s+['"]([^'"]+)\.scss['"]/g, function (_, name, path) {
        return "import " + name + " from '" + path + ".css'";
      })
    }), _extends2));
  }, {});

  var fixedCode = _extends({}, code, {
    modules: fixedModules
  });

  fixedCode.modules['/src/app.js'] = _extends({}, fixedCode.modules['/src/app.js'], {
    code: "\nimport './global.css';\n\nimport React from 'react';\nimport ReactDOM from 'react-dom';\nimport Page from '" + Object.keys(fixedModules).find(function (fpath) {
      return fpath.startsWith('/src/pages/');
    }) + "';\n\nReactDOM.render(<Page/>, document.getElementById('root'));\n"
  });
  fixedCode.modules['/package.json'] = _extends({}, fixedCode.modules['/package.json'], {
    code: "{\n  \"name\": \"demo\",\n  \"version\": \"1.0.0\",\n  \"dependencies\": {\n    \"react\": \"16.x\",\n    \"react-dom\": \"16.x\"\n  }\n}"
  });
  fixedCode.modules = pickKeys(fixedCode.modules, [// '/tsconfig.json',
  // '/jsconfig.json',
  // '/build.json',
  // '/abc.json',
  '/package.json', '/src/routes.js', '/src/app.js', '/src/constants.js', '/src/utils.js', '/src/i18n.js', '/src/global.css', '/src/index.js'].concat(Object.keys(fixedModules).filter(function (fpath) {
    return fpath.startsWith('/src/pages/');
  })));
  fixedCode.modules['/src/routes.js'] = _extends({}, fixedCode.modules['/src/routes.js'], {
    code: "\n"
  });
  fixedCode.modules['/src/global.css'] = {
    fpath: '/src/global.css',
    code: "\n@import \"~@alifd/next/dist/next.css\";\n\nbody {\n  -webkit-font-smoothing: antialiased;\n}\n"
  }; //   fixedCode.modules['/src/layouts/BasicLayout/components/Logo/index.module.css'] = {
  //     fpath: '/src/layouts/BasicLayout/components/Logo/index.module.css',
  //     code: `.logo{
  //   display: flex;
  //   align-items: center;
  //   justify-content: center;
  //   color: #333;
  //   font-weight: bold;
  //   font-size: 14px;
  //   line-height: 22px;
  // }
  // .logo:visited, .logo:link {
  //   color: #333;
  // }
  // .logo img {
  //   height: 24px;
  //   margin-right: 10px;
  // }`
  //   };

  return fixedCode;
}

function pickKeys(data, keys) {
  return keys.reduce(function (acc, key) {
    if (data[key]) {
      var _extends3;

      return _extends({}, acc, (_extends3 = {}, _extends3[key] = data[key], _extends3));
    }

    return acc;
  }, {});
}
